@@ -13,7 +13,7 @@ use utf8;
 
 my $term_encoding = Term::Encoding::get_encoding() || 'utf-8';
 
-our $VERSION = '0.18';
+our $VERSION = '0.19';
 
 sub opt_J { shift->_elem('opt_J', @_) }
 
@@ -45,7 +45,7 @@ sub grand_search_init {
     my @encodings =
       split ' ', $ENV{PERLDOCJP_ENCODINGS} || 'euc-jp shiftjis utf8';
 
-  if ($self->opt_J or ($pages->[0] && $pages->[0] =~ /^https?:/)) {
+  if (not $self->opt_F and ($self->opt_J or ($pages->[0] && $pages->[0] =~ /^https?:/))) {
     my $ua  = HTTP::Tiny->new(agent => "Pod-PerldocJp/$VERSION");
 
     my $api_url = $ENV{PERLDOCJP_SERVER} || 'http://perldoc.charsbar.org/api/pod';
